@@ -1,7 +1,7 @@
 /*********************************************************************
  * NAN - Native Abstractions for Node.js
  *
- * Copyright (c) 2016 NAN contributors
+ * Copyright (c) 2018 NAN contributors
  *
  * MIT License <https://github.com/nodejs/nan/blob/master/LICENSE.md>
  ********************************************************************/
@@ -17,7 +17,7 @@ NAN_METHOD(ReturnEmptyString) {
 NAN_MODULE_INIT(Init) {
   Set(target
     , New<v8::String>("r").ToLocalChecked()
-    , New<v8::FunctionTemplate>(ReturnEmptyString)->GetFunction()
+    , GetFunction(New<v8::FunctionTemplate>(ReturnEmptyString)).ToLocalChecked()
   );
 }
 
