@@ -1,7 +1,7 @@
 /*********************************************************************
  * NAN - Native Abstractions for Node.js
  *
- * Copyright (c) 2016 NAN contributors
+ * Copyright (c) 2018 NAN contributors
  *
  * MIT License <https://github.com/nodejs/nan/blob/master/LICENSE.md>
  ********************************************************************/
@@ -15,7 +15,8 @@ NAN_METHOD(ReturnNull) {
 NAN_MODULE_INIT(Init) {
   Nan::Set(target
     , Nan::New<v8::String>("r").ToLocalChecked()
-    , Nan::New<v8::FunctionTemplate>(ReturnNull)->GetFunction()
+    , Nan::GetFunction(Nan::New<v8::FunctionTemplate>(ReturnNull))
+      .ToLocalChecked()
   );
 }
 
